/*
############################################################################
# This program is used to test the basic functions of the SD file system.
# It implements simple versions of the cat, rm, ls, echo, cd, pwd, mkdir and
# rmdir commands plus the <, > and >> file redirection operators.
# The program starts up the file driver and then prompts for a command.
#
# Written by Dave Hein
# Copyright (c) 2011, 2012 Parallax, Inc.
# MIT Licensed
############################################################################
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <cog.h>
#include <ctype.h>
#include <propeller.h>
#include <unistd.h>
#include <sys/stat.h>
#include <dirent.h>
#include <sys/sd.h>

// The loader will automatically initialize the pin settings for the SD card
// if the board CFG file contains the SD pin description, and the ELF file
// contains the symbol table (i.e., the -s option was not specified).
// Otherwise, the mount function can be called by defining CALL_MOUNT and one
// one of the board types listed below.  You can also specify your own SD pin
// configuration by editing one of the examples that most closely matches your
// specific board.
#undef  CALL_MOUNT
#undef  SPINNERET_CARD
#undef  PROP_BOE
#undef  C3_CARD
#undef  PARALLEL_SPI

extern _Driver _SimpleSerialDriver;
extern _Driver _FileDriver;

/* This is a list of all drivers we can use in the
 * program. The default _InitIO function opens stdin,
 * stdout, and stderr based on the first driver in
 * the list (the serial driver, for us)
 */
_Driver *_driverlist[] = {
  &_SimpleSerialDriver,
  &_FileDriver,
  NULL
};

/*
 * Define MONITOR if you want the feature. It adds about 5KB in CMM mode.
 */

/* The program starts the file system. */
int main()
{
#ifdef CALL_MOUNT
    manual_mount();
#endif

#ifdef MONITOR
    monitor();
#else
    char buf[80];
    char abe[] = "Everthing you read on the internet is true. - Abraham Lincoln\n";
    int  size = strlen(abe)+1;

    FILE* fp = fopen("abe.txt", "w");
    if(fp) {
        fwrite(abe, 1, size, fp);
        fclose(fp);
    }
    fp = fopen("abe.txt", "r");
    if(fp) {
        fread(buf, 1, 80, fp);
        printf(buf);
        fclose(fp);
    }
#endif

    return 0;
}

/*
+--------------------------------------------------------------------
|  TERMS OF USE: MIT License
+--------------------------------------------------------------------
Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files
(the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge,
publish, distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+------------------------------------------------------------------
*/
